@@ -176,9 +176,13 @@ def getDFIBotEvents(connection, schema, address:str,is_active:bool=True,waiting_
     result = herokuDbAccess.fetchDataInDatabase(query, params, connection)    
     return result
 
-def getDFIBotControl(connection, schema, address:str):
-    query = sql.SQL("SELECT address,is_active FROM {0}.dfi_bot_control WHERE 1=1 AND address = %s").format(sql.Identifier(schema))
-    params = [address]
+def getDFIBotControl(connection, schema, address:str=None):
+    if address is None:
+        query = sql.SQL("SELECT address,is_active FROM {0}.dfi_bot_control").format(sql.Identifier(schema))
+        params = []
+    else:
+        query = sql.SQL("SELECT address,is_active FROM {0}.dfi_bot_control WHERE 1=1 AND address = %s").format(sql.Identifier(schema))
+        params = [address]
     
     result = herokuDbAccess.fetchDataInDatabase(query, params, connection)    
     return result
@@ -196,7 +200,6 @@ def putDFIBotControl(connection, schema, address:str,flag:str):
             flag,
             address
         )
-    print(query)
     result = herokuDbAccess.insertDataIntoDatabase(query, params, connection)    
     return result
 
@@ -238,7 +241,9 @@ def putDFIBotControl(connection, schema, address:str,flag:str):
 #         os.environ.get("HEROKU_DB_PORT"),
 #         os.environ.get("HEROKU_DB_DATABASE")
 #     )
-
+#     res = getDFIBotControl(connection,'prod','dfi1')
+#     print(res)
+#     print(len(res))
 #     res = putDFIBotcontrol(connection,'stage','dfi1','N')
 #     print(res)
     # data = {
