@@ -1,3 +1,4 @@
+from numpy import result_type
 import psycopg2
 
 def connect(user,pw,host,Port,database):
@@ -12,7 +13,14 @@ def fetchDataInDatabase(sql:str, params:list, connection):
     return result
 
 def insertDataIntoDatabase(sql:str, params:list, connection):    
+    
     cursor = connection.cursor()
-    cursor.execute(sql,params)
-    connection.commit()
-    cursor.close()
\ No newline at end of file
+    try:
+        cursor.execute(sql,params)
+        connection.commit()
+        cursor.close()
+        return None
+    except Exception as e:
+        connection.commit()
+        cursor.close()
+        return e
\ No newline at end of file
